Update of /cvsroot/jaxme/JaxMe2/src/net/sf/jaxme/generator/schema
In directory sc8-pr-cvs1:/tmp/cvs-serv9150/src/net/sf/jaxme/generator/schema
Modified Files:
SchemaSimpleObject.java
Log Message:
Added the JdbcSchemaWriter; see examples/jdbc/session.xsd and
docs/Reference.html. Added xs:schema/xs:annotation/xs:appinfo/jm:schema.
Index: SchemaSimpleObject.java
===================================================================
RCS file:
/cvsroot/jaxme/JaxMe2/src/net/sf/jaxme/generator/schema/SchemaSimpleObject.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -d -r1.1 -r1.2
--- SchemaSimpleObject.java 13 Aug 2002 18:54:04 -0000 1.1
+++ SchemaSimpleObject.java 31 Mar 2003 02:50:02 -0000 1.2
@@ -1,38 +1,52 @@
-package net.sf.jaxme.generator.schema;
-
-import net.sf.jaxme.generator.types.SchemaSimpleType;
-
-/** <p>A common base class for <code>SchemaSimpleElement</code>,
- * <code>SchemaAttribute</code>.</p>
- * <p>To determine the actual types, use the methods
- * <code>isAttribute()</code>, <code>isChildElement()</code>
- * and <code>isContent</code>, either of which will return
- * true.</p>
- *
- * @author <a href="mailto:[EMAIL PROTECTED]">Jochen Wiedmann</a>
- * @version $Id$
- */
-public interface SchemaSimpleObject extends SchemaObject {
- /** <p>Returns whether this object is in fact an attribute.
- * This is the case if, and only if, the object may be casted
- * to <code>SchemaAttribute</code>.</p>
- */
- public boolean isAttribute();
-
- /** <p>Returns whether this object is in fact a child element.
- * This is the case if, and only if, the object may be casted
- * to <code>SchemaSimpleElement</code>.</p>
- */
- public boolean isChildElement();
-
- /** <p>Returns whether this object is in fact the content of
- * a complex element with simple content. This is the case,
- * if and only if, the object may be casted to
- * <code>ComplexTypeContent</code>.</p>
- */
- public boolean isContent();
-
- /** <p>Shortcut for <code>(SchemaSimpleType) getSchemaType()</code>.</p>
- */
- public SchemaSimpleType getSchemaSimpleType();
-}
+package net.sf.jaxme.generator.schema;
+
+import net.sf.jaxme.generator.types.SchemaSimpleType;
+
+/** <p>A common base class for <code>SchemaSimpleElement</code>,
+ * <code>SchemaAttribute</code>.</p>
+ * <p>To determine the actual types, use the methods
+ * <code>isAttribute()</code>, <code>isChildElement()</code>
+ * and <code>isContent</code>, either of which will return
+ * true.</p>
+ *
+ * @author <a href="mailto:[EMAIL PROTECTED]">Jochen Wiedmann</a>
+ * @version $Id$
+ */
+public interface SchemaSimpleObject extends SchemaObject {
+ /** <p>Returns whether this object is in fact an attribute.
+ * This is the case if, and only if, the object may be casted
+ * to <code>SchemaAttribute</code>.</p>
+ */
+ public boolean isAttribute();
+
+ /** <p>Returns whether this object is in fact a child element.
+ * This is the case if, and only if, the object may be casted
+ * to <code>SchemaSimpleElement</code>.</p>
+ */
+ public boolean isChildElement();
+
+ /** <p>Returns whether this object is in fact the content of
+ * a complex element with simple content. This is the case,
+ * if and only if, the object may be casted to
+ * <code>ComplexTypeContent</code>.</p>
+ */
+ public boolean isContent();
+
+ /** <p>Shortcut for <code>(SchemaSimpleType) getSchemaType()</code>.</p>
+ */
+ public SchemaSimpleType getSchemaSimpleType();
+
+ /** <p>If the object is part of a primary key: Sets the objects
+ * index within the primary key.</p>
+ * @param pIndex Primary key index or null, if the object isn't part of
+ * a primary key
+ */
+ public void setPrimaryKeyIndex(Short pIndex);
+
+ /** <p>If the object is part of a primary key: Returns the objects
+ * index within the primary key.</p>
+ * @return Primary key index or null, if the object isn't part of
+ * a primary key
+ */
+ public Short getPrimaryKeyIndex();
+}
-------------------------------------------------------
This SF.net email is sponsored by:
The Definitive IT and Networking Event. Be There!
NetWorld+Interop Las Vegas 2003 -- Register today!
http://ads.sourceforge.net/cgi-bin/redirect.pl?keyn0001en
_______________________________________________
Jaxme-jaxb-dev mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/jaxme-jaxb-dev